@@ -17,11 +17,11 @@ def to_xml(viewpoint):
     children = []
 
     if (components := viewpoint.get("components")) is not None:
-        visibility = components["visibility"]
+        visibility = components.get("visibility")
 
         components_children = []
 
-        if (view_setup_hints := visibility.get("view_setup_hints")) is not None:
+        if visibility and (view_setup_hints := visibility.get("view_setup_hints")) is not None:
             components_children.append(ViewSetupHints.to_xml(view_setup_hints))
 
         xml_selections = [
@@ -32,7 +32,8 @@ def to_xml(viewpoint):
         if xml_selections:
             components_children.append(e.Selection(*xml_selections))
 
-        components_children.append(Visibility.to_xml(visibility))
+        if visibility:
+            components_children.append(Visibility.to_xml(visibility))
 
         xml_colorings = [Color.to_xml(coloring) for coloring in components.get("coloring", [])]
         if xml_colorings:
@@ -68,16 +69,17 @@ def to_python(xml):
     if (orthogonal_camera := xml.find("OrthogonalCamera")) is not None:
         viewpoint["orthogonal_camera"] = OrthogonalCamera.to_python(orthogonal_camera)
 
-    viewpoint["lines"] = [
-        Line.to_python(line.find("Line"))
-        for line in xml.findall("Lines")
-        if line.find("Line") is not None
-    ]
-    viewpoint["clipping_planes"] = [
-        ClippingPlane.to_python(plane.find("ClippingPlane"))
-        for plane in xml.findall("ClippingPlanes")
-        if plane.find("ClippingPlane") is not None
-    ]
+    if (lines := xml.find("Lines")) is not None:
+        viewpoint["lines"] = [
+            Line.to_python(line)
+            for line in lines.findall("Line")
+        ]
+    if (planes := xml.find("ClippingPlanes")) is not None:
+        viewpoint["clipping_planes"] = [
+            ClippingPlane.to_python(plane)
+            for plane in planes.findall("ClippingPlane")
+        ]
+
     if (components := xml.find("Components")) is not None:
         viewpoint["components"] = {}
         if (selection := components.find("Selection")) is not None:
